Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/avrprog_read_signature_simpletest.py
    :caption: examples/avrprog_read_signature_simpletest.py
    :linenos:

.. literalinclude:: ../examples/avrprog_program_trinket85.py
    :caption: examples/avrprog_program_trinket85.py
    :linenos:

.. literalinclude:: ../examples/avrprog_program_uno328.py
    :caption: examples/avrprog_program_uno328.py
    :linenos:

.. literalinclude:: ../examples/avrprog_program_mega2560.py
    :caption: examples/avrprog_program_mega2560.py
    :linenos:
